"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QTabBar(QWidget):
    """
    https://doc.qt.io/qt-6/qtabbar.html

    **Detailed Description**

    QTabBar is straightforward to use; it draws the tabs using one of the
    predefined **shapes** , and emits a signal when a tab is selected. It can be
    subclassed to tailor the look and feel. Qt also provides a ready-made
    **QTabWidget** .

    Each tab has a **tabText** (), an optional **tabIcon** (), an optional
    **tabToolTip** (), optional **tabWhatsThis** () and optional **tabData** ().
    The tabs's attributes can be changed with **setTabText** (), **setTabIcon**
    (), **setTabToolTip** (), **setTabWhatsThis**  and **setTabData** (). Each
    tabs can be enabled or disabled individually with **setTabEnabled** ().

    Each tab can display text in a distinct color. The current text color for a
    tab can be found with the **tabTextColor** () function. Set the text color
    for a particular tab with **setTabTextColor** ().

    Tabs are added using **addTab** (), or inserted at particular positions
    using **insertTab** (). The total number of tabs is given by **count** ().
    Tabs can be removed from the tab bar with **removeTab** (). Combining
    **removeTab** () and **insertTab** () allows you to move tabs to different
    positions.

    The **shape**  property defines the tabs' appearance. The choice of shape is
    a matter of taste, although tab dialogs (for preferences and similar)
    invariably use **RoundedNorth** . Tab controls in windows other than dialogs
    almost always use either **RoundedSouth**  or **TriangularSouth** . Many
    spreadsheets and other tab controls in which all the pages are essentially
    similar use **TriangularSouth** , whereas **RoundedSouth**  is used mostly
    when the pages are different (e.g. a multi-page tool palette). The default
    in QTabBar is **RoundedNorth** .

    The most important part of QTabBar's API is the **currentChanged** ()
    signal. This is emitted whenever the current tab changes (even at startup,
    when the current tab changes from 'none'). There is also a slot,
    **setCurrentIndex** (), which can be used to select a tab programmatically.
    The function **currentIndex** () returns the index of the current tab,
    **count**  holds the number of tabs.

    QTabBar creates automatic mnemonic keys in the manner of **QAbstractButton**
    ; e.g. if a tab's label is "&Graphics", Alt+G becomes a shortcut key for
    switching to that tab.

    The following virtual functions may need to be reimplemented in order to
    tailor the look and feel or store extra data with each tab:

    * **tabSizeHint** () calcuates the size of a tab.
      * **tabInserted** ()
    notifies that a new tab was added.
      * **tabRemoved** () notifies that a tab
    was removed.
      * **tabLayoutChange** () notifies that the tabs have been re-
    laid out.
      * **paintEvent** () paints all tabs.

    For subclasses, you might also need the **tabRect** () functions which
    returns the visual geometry of a single tab.

    ![Screenshot of a Fusion style tab bar](images/fusion-tabbar.png)A tab bar
    shown in the **Fusion widget style** .
    ![Screenshot of a truncated Fusion
    tab bar](images/fusion-tabbar-truncated.png)A truncated tab bar shown in the
    Fusion widget style.

    **See also** **QTabWidget** .
    """

    class SelectionBehavior(enum.Enum):
        SelectLeftTab: QTabBar = ...
        SelectRightTab: QTabBar = ...
        SelectPreviousTab: QTabBar = ...

    class ButtonPosition(enum.Enum):
        LeftSide: QTabBar = ...
        RightSide: QTabBar = ...

    class Shape(enum.Enum):
        RoundedNorth: QTabBar = ...
        RoundedSouth: QTabBar = ...
        RoundedWest: QTabBar = ...
        RoundedEast: QTabBar = ...
        TriangularNorth: QTabBar = ...
        TriangularSouth: QTabBar = ...
        TriangularWest: QTabBar = ...
        TriangularEast: QTabBar = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#QTabBar

        **QTabBar::QTabBar(QWidget * parent = nullptr)**

        Creates a new tab bar with the given **parent**.
        """
        ...

    def setTabVisible(self, index: int, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabVisible

        **[since 5.15] void QTabBar::setTabVisible(int index , bool visible )**

        If **visible** is true, make the tab at position **index** visible,
        otherwise make it hidden.

        This function was introduced in Qt 5.15.

        **See also** **isTabVisible** ().
        """
        ...

    def isTabVisible(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#isTabVisible

        **[since 5.15] bool QTabBar::isTabVisible(int index ) const**

        Returns true if the tab at position **index** is visible; otherwise
        returns false.

        This function was introduced in Qt 5.15.
        """
        ...

    def setAccessibleTabName(self, index: int, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setAccessibleTabName

        **void QTabBar::setAccessibleTabName(int index , const QString & name
        )**

        Sets the accessibleName of the tab at position **index** to **name**.

        **See also** **accessibleTabName** ().
        """
        ...

    def accessibleTabName(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabbar.html#accessibleTabName

        **QString QTabBar::accessibleTabName(int index ) const**

        Returns the accessibleName of the tab at position **index** , or an
        empty string if **index** is out of range.

        **See also** **setAccessibleTabName** ().
        """
        ...

    def timerEvent(self, event: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#timerEvent

        **[override virtual protected] void QTabBar::timerEvent(QTimerEvent *
        event )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def setChangeCurrentOnDrag(self, change: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#changeCurrentOnDrag-prop

        **[since 5.4] changeCurrentOnDrag : bool**

        If true, then the current tab is automatically changed when dragging
        over the tabbar.

        **Note:** You should also set acceptDrops property to true to make this
        feature work.

        By default, this property is false.

        This property was introduced in Qt 5.4.

        **Access functions:**

        bool **changeCurrentOnDrag** () const
        void **setChangeCurrentOnDrag**
        (bool **change** )
        """
        ...

    def changeCurrentOnDrag(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#changeCurrentOnDrag-prop

        **[since 5.4] changeCurrentOnDrag : bool**

        If true, then the current tab is automatically changed when dragging
        over the tabbar.

        **Note:** You should also set acceptDrops property to true to make this
        feature work.

        By default, this property is false.

        This property was introduced in Qt 5.4.

        **Access functions:**

        bool **changeCurrentOnDrag** () const
        void **setChangeCurrentOnDrag**
        (bool **change** )
        """
        ...

    def setAutoHide(self, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#autoHide-prop

        **[since 5.4] autoHide : bool**

        If true, the tab bar is automatically hidden when it contains less than
        2 tabs.

        By default, this property is false.

        This property was introduced in Qt 5.4.

        **Access functions:**

        bool **autoHide** () const
        void **setAutoHide** (bool **hide** )

        **See also** **QWidget::visible** .
        """
        ...

    def autoHide(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#autoHide-prop

        **[since 5.4] autoHide : bool**

        If true, the tab bar is automatically hidden when it contains less than
        2 tabs.

        By default, this property is false.

        This property was introduced in Qt 5.4.

        **Access functions:**

        bool **autoHide** () const
        void **setAutoHide** (bool **hide** )

        **See also** **QWidget::visible** .
        """
        ...

    def minimumTabSizeHint(self, index: int) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabbar.html#minimumTabSizeHint

        **[virtual protected, since 5.0] QSize QTabBar::minimumTabSizeHint(int
        index ) const**

        Returns the minimum tab size hint for the tab at position **index**.

        This function was introduced in Qt 5.0.
        """
        ...

    def wheelEvent(self, event: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#wheelEvent

        **[override virtual protected] void QTabBar::wheelEvent(QWheelEvent *
        event )**

        Reimplements: **QWidget::wheelEvent** (QWheelEvent *event).
        """
        ...

    def mouseDoubleClickEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QTabBar::mouseDoubleClickEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseDoubleClickEvent** (QMouseEvent *event).
        """
        ...

    def hideEvent(self, a0: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#hideEvent

        **[override virtual protected] void QTabBar::hideEvent(QHideEvent *)**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def setDocumentMode(self, set: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#documentMode-prop

        **documentMode : bool**

        This property holds whether or not the tab bar is rendered in a mode
        suitable for the main window.

        This property is used as a hint for styles to draw the tabs in a
        different way then they would normally look in a tab widget. On macOS
        this will look similar to the tabs in Safari or Sierra's Terminal.app.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool **set**
        )

        **See also** **QTabWidget::documentMode** .
        """
        ...

    def documentMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#documentMode-prop

        **documentMode : bool**

        This property holds whether or not the tab bar is rendered in a mode
        suitable for the main window.

        This property is used as a hint for styles to draw the tabs in a
        different way then they would normally look in a tab widget. On macOS
        this will look similar to the tabs in Safari or Sierra's Terminal.app.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool **set**
        )

        **See also** **QTabWidget::documentMode** .
        """
        ...

    def setMovable(self, movable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#movable-prop

        **movable : bool**

        This property holds whether the user can move the tabs within the tabbar
        area.

        By default, this property is `false`;

        **Access functions:**

        bool **isMovable** () const
        void **setMovable** (bool **movable** )
        """
        ...

    def isMovable(self) -> bool:
        ...

    def setExpanding(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#expanding-prop

        **expanding : bool**

        When expanding is true **QTabBar**  will expand the tabs to use the
        empty space.

        By default the value is true.

        **Access functions:**

        bool **expanding** () const
        void **setExpanding** (bool **enabled** )

        **See also** **QTabWidget::documentMode** .
        """
        ...

    def expanding(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#expanding-prop

        **expanding : bool**

        When expanding is true **QTabBar**  will expand the tabs to use the
        empty space.

        By default the value is true.

        **Access functions:**

        bool **expanding** () const
        void **setExpanding** (bool **enabled** )

        **See also** **QTabWidget::documentMode** .
        """
        ...

    def setSelectionBehaviorOnRemove(
        self, behavior: "QTabBar.SelectionBehavior"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#selectionBehaviorOnRemove-prop

        **selectionBehaviorOnRemove : SelectionBehavior**

        What tab should be set as current when **removeTab**  is called if the
        removed tab is also the current tab.

        By default the value is **SelectRightTab** .

        **Access functions:**

        QTabBar::SelectionBehavior **selectionBehaviorOnRemove** () const
        void
        **setSelectionBehaviorOnRemove** (QTabBar::SelectionBehavior
        **behavior** )

        **See also** **removeTab** ().
        """
        ...

    def selectionBehaviorOnRemove(self) -> "QTabBar.SelectionBehavior":
        """
        https://doc.qt.io/qt-6/qtabbar.html#selectionBehaviorOnRemove-prop

        **selectionBehaviorOnRemove : SelectionBehavior**

        What tab should be set as current when **removeTab**  is called if the
        removed tab is also the current tab.

        By default the value is **SelectRightTab** .

        **Access functions:**

        QTabBar::SelectionBehavior **selectionBehaviorOnRemove** () const
        void
        **setSelectionBehaviorOnRemove** (QTabBar::SelectionBehavior
        **behavior** )

        **See also** **removeTab** ().
        """
        ...

    def tabButton(self, index: int, position: "QTabBar.ButtonPosition") -> QWidget:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabButton

        **QWidget *QTabBar::tabButton(int index , QTabBar::ButtonPosition
        position ) const**

        Returns the widget set a tab **index** and **position** or `nullptr` if
        one is not set.

        **See also** **setTabButton** ().
        """
        ...

    def setTabButton(
        self, index: int, position: "QTabBar.ButtonPosition", widget: QWidget
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabButton

        **void QTabBar::setTabButton(int index , QTabBar::ButtonPosition
        position , QWidget * widget )**

        Sets **widget** on the tab **index**. The widget is placed on the left
        or right hand side depending upon the **position**.

        Any previously set widget in **position** is hidden.

        The tab bar will take ownership of the widget and so all widgets set
        here will be deleted by the tab bar when it is destroyed unless you
        separately reparent the widget after setting some other widget (or
        `nullptr`).

        **See also** **tabButton** () and **tabsClosable** ().
        """
        ...

    def setTabsClosable(self, closable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabsClosable-prop

        **tabsClosable : bool**

        This property holds whether or not a tab bar should place close buttons
        on each tab

        When tabsClosable is set to true a close button will appear on the tab
        on either the left or right hand side depending upon the style. When the
        button is clicked the tab the signal **tabCloseRequested**  will be
        emitted.

        By default the value is false.

        **Access functions:**

        bool **tabsClosable** () const
        void **setTabsClosable** (bool
        **closable** )

        **See also** **setTabButton** () and **tabRemoved** ().
        """
        ...

    def tabsClosable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabsClosable-prop

        **tabsClosable : bool**

        This property holds whether or not a tab bar should place close buttons
        on each tab

        When tabsClosable is set to true a close button will appear on the tab
        on either the left or right hand side depending upon the style. When the
        button is clicked the tab the signal **tabCloseRequested**  will be
        emitted.

        By default the value is false.

        **Access functions:**

        bool **tabsClosable** () const
        void **setTabsClosable** (bool
        **closable** )

        **See also** **setTabButton** () and **tabRemoved** ().
        """
        ...

    def moveTab(self, from_: int, to: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#moveTab

        **void QTabBar::moveTab(int from , int to )**

        Moves the item at index position **from** to index position **to**.

        **See also** **tabMoved** () and **tabLayoutChange** ().
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#changeEvent

        **[override virtual protected] void QTabBar::changeEvent(QEvent * event
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#keyPressEvent

        **[override virtual protected] void QTabBar::keyPressEvent(QKeyEvent *
        event )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#mouseReleaseEvent

        **[override virtual protected] void
        QTabBar::mouseReleaseEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#mouseMoveEvent

        **[override virtual protected] void QTabBar::mouseMoveEvent(QMouseEvent
        * event )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#mousePressEvent

        **[override virtual protected] void QTabBar::mousePressEvent(QMouseEvent
        * event )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#paintEvent

        **[override virtual protected] void QTabBar::paintEvent(QPaintEvent *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#showEvent

        **[override virtual protected] void QTabBar::showEvent(QShowEvent *)**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#resizeEvent

        **[override virtual protected] void QTabBar::resizeEvent(QResizeEvent
        *)**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#event

        **[override virtual protected] bool QTabBar::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def tabLayoutChange(self) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabLayoutChange

        **[virtual protected] void QTabBar::tabLayoutChange()**

        This virtual handler is called whenever the tab layout changes.

        **See also** **tabRect** ().
        """
        ...

    def tabRemoved(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabRemoved

        **[virtual protected] void QTabBar::tabRemoved(int index )**

        This virtual handler is called after a tab was removed from position
        **index**.

        **See also** **tabInserted** ().
        """
        ...

    def tabInserted(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabInserted

        **[virtual protected] void QTabBar::tabInserted(int index )**

        This virtual handler is called after a new tab was added or inserted at
        position **index**.

        **See also** **tabRemoved** ().
        """
        ...

    def tabSizeHint(self, index: int) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabSizeHint

        **[virtual protected] QSize QTabBar::tabSizeHint(int index ) const**

        Returns the size hint for the tab at position **index**.
        """
        ...

    def initStyleOption(self, option: QStyleOptionTab, tabIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#initStyleOption

        **[virtual protected] void QTabBar::initStyleOption(QStyleOptionTab *
        option , int tabIndex ) const**

        Initialize **option** with the values from the tab at **tabIndex**. This
        method is useful for subclasses when they need a **QStyleOptionTab** ,
        but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** () and
        **QTabWidget::initStyleOption** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index of the tab bar's visible tab

        The current index is -1 if there is no current tab.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )
        """
        ...

    def usesScrollButtons(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#usesScrollButtons-prop

        **usesScrollButtons : bool**

        This property holds whether or not a tab bar should use buttons to
        scroll tabs when it has many tabs.

        When there are too many tabs in a tab bar for its size, the tab bar can
        either choose to expand its size or to add buttons that allow you to
        scroll through the tabs.

        By default the value is style-dependent.

        **Access functions:**

        bool **usesScrollButtons** () const
        void **setUsesScrollButtons**
        (bool **useButtons** )

        **See also** **elideMode** , **QTabWidget::usesScrollButtons** , and
        **QStyle::SH_TabBar_PreferNoArrows** .

        **Member Function Documentation**
        """
        ...

    def setUsesScrollButtons(self, useButtons: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#usesScrollButtons-prop

        **usesScrollButtons : bool**

        This property holds whether or not a tab bar should use buttons to
        scroll tabs when it has many tabs.

        When there are too many tabs in a tab bar for its size, the tab bar can
        either choose to expand its size or to add buttons that allow you to
        scroll through the tabs.

        By default the value is style-dependent.

        **Access functions:**

        bool **usesScrollButtons** () const
        void **setUsesScrollButtons**
        (bool **useButtons** )

        **See also** **elideMode** , **QTabWidget::usesScrollButtons** , and
        **QStyle::SH_TabBar_PreferNoArrows** .

        **Member Function Documentation**
        """
        ...

    def setElideMode(self, a0: QtCore.Qt.TextElideMode) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#elideMode-prop

        **elideMode : Qt::TextElideMode**

        how to elide text in the tab bar

        This property controls how items are elided when there is not enough
        space to show them for a given tab bar size.

        By default the value is style-dependent.

        **Access functions:**

        Qt::TextElideMode **elideMode** () const
        void **setElideMode**
        (Qt::TextElideMode **mode** )

        **See also** **QTabWidget::elideMode** , **usesScrollButtons** , and
        **QStyle::SH_TabBar_ElideMode** .
        """
        ...

    def elideMode(self) -> QtCore.Qt.TextElideMode:
        """
        https://doc.qt.io/qt-6/qtabbar.html#elideMode-prop

        **elideMode : Qt::TextElideMode**

        how to elide text in the tab bar

        This property controls how items are elided when there is not enough
        space to show them for a given tab bar size.

        By default the value is style-dependent.

        **Access functions:**

        Qt::TextElideMode **elideMode** () const
        void **setElideMode**
        (Qt::TextElideMode **mode** )

        **See also** **QTabWidget::elideMode** , **usesScrollButtons** , and
        **QStyle::SH_TabBar_ElideMode** .
        """
        ...

    def setIconSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size for icons in the tab bar

        The default value is style-dependent. `iconSize` is a maximum size;
        icons that are smaller are not scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )

        **See also** **QTabWidget::iconSize** .
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabbar.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size for icons in the tab bar

        The default value is style-dependent. `iconSize` is a maximum size;
        icons that are smaller are not scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )

        **See also** **QTabWidget::iconSize** .
        """
        ...

    def drawBase(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#drawBase-prop

        **drawBase : bool**

        defines whether or not tab bar should draw its base.

        If true then **QTabBar**  draws a base in relation to the styles
        overlap. Otherwise only the tabs are drawn.

        **Access functions:**

        bool **drawBase** () const
        void **setDrawBase** (bool **drawTheBase**
        )

        **See also** **QStyle::pixelMetric** (),
        **QStyle::PM_TabBarBaseOverlap** , and **QStyleOptionTabBarBase** .
        """
        ...

    def setDrawBase(self, drawTheBase: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#drawBase-prop

        **drawBase : bool**

        defines whether or not tab bar should draw its base.

        If true then **QTabBar**  draws a base in relation to the styles
        overlap. Otherwise only the tabs are drawn.

        **Access functions:**

        bool **drawBase** () const
        void **setDrawBase** (bool **drawTheBase**
        )

        **See also** **QStyle::pixelMetric** (),
        **QStyle::PM_TabBarBaseOverlap** , and **QStyleOptionTabBarBase** .
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabbar.html#minimumSizeHint

        **[override virtual] QSize QTabBar::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabbar.html#sizeHint

        **[override virtual] QSize QTabBar::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#count-prop

        **[read-only] count : const int**

        This property holds the number of tabs in the tab bar

        **Access functions:**

        int **count** () const
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index of the tab bar's visible tab

        The current index is -1 if there is no current tab.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )
        """
        ...

    def tabRect(self, index: int) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabRect

        **QRect QTabBar::tabRect(int index ) const**

        Returns the visual rectangle of the tab at position **index** , or a
        null rectangle if **index** is hidden, or out of range.
        """
        ...

    def tabAt(self, pos: QtCore.QPoint) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabAt

        **int QTabBar::tabAt(const QPoint & position ) const**

        Returns the index of the tab that covers **position** or -1 if no tab
        covers **position** ;
        """
        ...

    def tabData(self, index: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabData

        **QVariant QTabBar::tabData(int index ) const**

        Returns the data of the tab at position **index** , or a null variant if
        **index** is out of range.

        **See also** **setTabData** ().
        """
        ...

    def setTabData(self, index: int, data: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabData

        **void QTabBar::setTabData(int index , const QVariant & data )**

        Sets the data of the tab at position **index** to **data**.

        **See also** **tabData** ().
        """
        ...

    def tabWhatsThis(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabWhatsThis

        **QString QTabBar::tabWhatsThis(int index ) const**

        Returns the What's This help text of the tab at position **index** , or
        an empty string if **index** is out of range.

        **See also** **setTabWhatsThis** ().
        """
        ...

    def setTabWhatsThis(self, index: int, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabWhatsThis

        **void QTabBar::setTabWhatsThis(int index , const QString & text )**

        Sets the What's This help text of the tab at position **index** to
        **text**.

        **See also** **tabWhatsThis** ().
        """
        ...

    def tabToolTip(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabToolTip

        **QString QTabBar::tabToolTip(int index ) const**

        Returns the tool tip of the tab at position **index** , or an empty
        string if **index** is out of range.

        **See also** **setTabToolTip** ().
        """
        ...

    def setTabToolTip(self, index: int, tip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabToolTip

        **void QTabBar::setTabToolTip(int index , const QString & tip )**

        Sets the tool tip of the tab at position **index** to **tip**.

        **See also** **tabToolTip** ().
        """
        ...

    def setTabIcon(self, index: int, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabIcon

        **void QTabBar::setTabIcon(int index , const QIcon & icon )**

        Sets the icon of the tab at position **index** to **icon**.

        **See also** **tabIcon** ().
        """
        ...

    def tabIcon(self, index: int) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabIcon

        **QIcon QTabBar::tabIcon(int index ) const**

        Returns the icon of the tab at position **index** , or a null icon if
        **index** is out of range.

        **See also** **setTabIcon** ().
        """
        ...

    def setTabTextColor(
        self,
        index: int,
        color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabTextColor

        **void QTabBar::setTabTextColor(int index , const QColor & color )**

        Sets the color of the text in the tab with the given **index** to the
        specified **color**.

        If an invalid color is specified, the tab will use the **QTabBar**
        foreground role instead.

        **See also** **tabTextColor** ().
        """
        ...

    def tabTextColor(self, index: int) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabTextColor

        **QColor QTabBar::tabTextColor(int index ) const**

        Returns the text color of the tab with the given **index** , or a
        invalid color if **index** is out of range.

        **See also** **setTabTextColor** ().
        """
        ...

    def setTabText(self, index: int, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabText

        **void QTabBar::setTabText(int index , const QString & text )**

        Sets the text of the tab at position **index** to **text**.

        **See also** **tabText** ().
        """
        ...

    def tabText(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabText

        **QString QTabBar::tabText(int index ) const**

        Returns the text of the tab at position **index** , or an empty string
        if **index** is out of range.

        **See also** **setTabText** ().
        """
        ...

    def setTabEnabled(self, index: int, a1: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#setTabEnabled

        **void QTabBar::setTabEnabled(int index , bool enabled )**

        If **enabled** is true then the tab at position **index** is enabled;
        otherwise the item at position **index** is disabled.

        **See also** **isTabEnabled** ().
        """
        ...

    def isTabEnabled(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtabbar.html#isTabEnabled

        **bool QTabBar::isTabEnabled(int index ) const**

        Returns `true` if the tab at position **index** is enabled; otherwise
        returns `false`.
        """
        ...

    def removeTab(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#removeTab

        **void QTabBar::removeTab(int index )**

        Removes the tab at position **index**.

        **See also** **SelectionBehavior** .
        """
        ...

    @typing.overload
    def insertTab(self, index: int, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#insertTab

        **int QTabBar::insertTab(int index , const QString & text )**

        Inserts a new tab with text **text** at position **index**. If **index**
        is out of range, the new tab is appened. Returns the new tab's index.
        """
        ...

    @typing.overload
    def insertTab(self, index: int, icon: QtGui.QIcon, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#insertTab-1

        **int QTabBar::insertTab(int index , const QIcon & icon , const QString
        & text )**

        This is an overloaded function.

        Inserts a new tab with icon **icon** and text **text** at position
        **index**. If **index** is out of range, the new tab is appended.
        Returns the new tab's index.

        If the **QTabBar**  was empty before this function is called, the
        inserted tab becomes the current tab.

        Inserting a new tab at an index less than or equal to the current index
        will increment the current index, but keep the current tab.
        """
        ...

    @typing.overload
    def addTab(self, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#addTab

        **int QTabBar::addTab(const QString & text )**

        Adds a new tab with text **text**. Returns the new tab's index.
        """
        ...

    @typing.overload
    def addTab(self, icon: QtGui.QIcon, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabbar.html#addTab-1

        **int QTabBar::addTab(const QIcon & icon , const QString & text )**

        This is an overloaded function.

        Adds a new tab with icon **icon** and text **text**. Returns the new
        tab's index.
        """
        ...

    def setShape(self, shape: "QTabBar.Shape") -> None:
        """
        https://doc.qt.io/qt-6/qtabbar.html#shape-prop

        **shape : Shape**

        This property holds the shape of the tabs in the tab bar

        Possible values for this property are described by the Shape enum.

        **Access functions:**

        QTabBar::Shape **shape** () const
        void **setShape** (QTabBar::Shape
        **shape** )
        """
        ...

    def shape(self) -> "QTabBar.Shape":
        """
        https://doc.qt.io/qt-6/qtabbar.html#shape-prop

        **shape : Shape**

        This property holds the shape of the tabs in the tab bar

        Possible values for this property are described by the Shape enum.

        **Access functions:**

        QTabBar::Shape **shape** () const
        void **setShape** (QTabBar::Shape
        **shape** )
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabbar.html#currentChanged

        **[signal] void QTabBar::currentChanged(int index )**

        This signal is emitted when the tab bar's current tab changes. The new
        current has the given **index** , or -1 if there isn't a new one (for
        example, if there are no tab in the **QTabBar** )

        **Note:** Notifier signal for property **currentIndex** .
        """
        ...

    @property
    def tabBarClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabBarClicked

        **[signal, since 5.2] void QTabBar::tabBarClicked(int index )**

        This signal is emitted when user clicks on a tab at an **index**.

        **index** is the index of a clicked tab, or -1 if no tab is under the
        cursor.

        This function was introduced in Qt 5.2.
        """
        ...

    @property
    def tabBarDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabBarDoubleClicked

        **[signal, since 5.2] void QTabBar::tabBarDoubleClicked(int index )**

        This signal is emitted when the user double clicks on a tab at
        **index**.

        **index** refers to the tab clicked, or -1 if no tab is under the
        cursor.

        This function was introduced in Qt 5.2.
        """
        ...

    @property
    def tabCloseRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabCloseRequested

        **[signal] void QTabBar::tabCloseRequested(int index )**

        This signal is emitted when the close button on a tab is clicked. The
        **index** is the index that should be removed.

        **See also** **setTabsClosable** ().
        """
        ...

    @property
    def tabMoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabbar.html#tabMoved

        **[signal] void QTabBar::tabMoved(int from , int to )**

        This signal is emitted when the tab has moved the tab at index position
        **from** to index position **to**.

        note: **QTabWidget**  will automatically move the page when this signal
        is emitted from its tab bar.

        **See also** **moveTab** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtWidgets import *
import enum


class QStyleHintReturn(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstylehintreturn.html

    **Detailed Description**

    QStyleHintReturn and its subclasses are used to pass information from a
    style back to the querying widget. This is most useful when the return value
    from **QStyle::styleHint** () does not provide enough detail; for example,
    when a mask is to be returned.
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleHintReturn = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleHintReturn = ...

    class HintReturnType(enum.Enum):
        SH_Default: QStyleHintReturn = ...
        SH_Mask: QStyleHintReturn = ...
        SH_Variant: QStyleHintReturn = ...

    type: int = ...
    version: int = ...

    @typing.overload
    def __init__(self, version: int = ..., type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturn.html#QStyleHintReturn

        **QStyleHintReturn::QStyleHintReturn(int version =
        QStyleOption::Version, int type = SH_Default)**

        Constructs a QStyleHintReturn with version **version** and type
        **type**.

        The version has no special meaning for QStyleHintReturn; it can be used
        by subclasses to distinguish between different version of the same hint
        type.

        **See also** **QStyleOption::version**  and **QStyleOption::type** .
        """
        ...

    @typing.overload
    def __init__(self, a0: "QStyleHintReturn") -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturn.html#QStyleHintReturn

        **QStyleHintReturn::QStyleHintReturn(int version =
        QStyleOption::Version, int type = SH_Default)**

        Constructs a QStyleHintReturn with version **version** and type
        **type**.

        The version has no special meaning for QStyleHintReturn; it can be used
        by subclasses to distinguish between different version of the same hint
        type.

        **See also** **QStyleOption::version**  and **QStyleOption::type** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QTabWidget(QWidget):
    """
    https://doc.qt.io/qt-6/qtabwidget.html

    **Detailed Description**

    ![](images/windows-tabwidget.png)

    A tab widget provides a tab bar (see **QTabBar** ) and a "page area" that is
    used to display pages related to each tab. By default, the tab bar is shown
    above the page area, but different configurations are available (see
    **TabPosition** ). Each tab is associated with a different widget (called a
    page). Only the current page is shown in the page area; all the other pages
    are hidden. The user can show a different page by clicking on its tab or by
    pressing its Alt+ **letter** shortcut if it has one.

    The normal way to use QTabWidget is to do the following:

    1. Create a QTabWidget.
      2. Create a **QWidget**  for each of the pages in
    the tab dialog, but do not specify parent widgets for them.
      3. Insert
    child widgets into the page widget, using layouts to position them as
    normal.
      4. Call **addTab** () or **insertTab** () to put the page widgets
    into the tab widget, giving each tab a suitable label with an optional
    keyboard shortcut.

    The position of the tabs is defined by **tabPosition** , their shape by
    **tabShape** .

    The signal **currentChanged** () is emitted when the user selects a page.

    The current page index is available as **currentIndex** (), the current page
    widget with **currentWidget** (). You can retrieve a pointer to a page
    widget with a given index using **widget** (), and can find the index
    position of a widget with **indexOf** (). Use **setCurrentWidget** () or
    **setCurrentIndex** () to show a particular page.

    You can change a tab's text and icon using **setTabText** () or
    **setTabIcon** (). A tab and its associated page can be removed with
    **removeTab** ().

    Each tab is either enabled or disabled at any given time (see
    **setTabEnabled** ()). If a tab is enabled, the tab text is drawn normally
    and the user can select that tab. If it is disabled, the tab is drawn in a
    different way and the user cannot select that tab. Note that even if a tab
    is disabled, the page can still be visible, for example if all of the tabs
    happen to be disabled.

    Tab widgets can be a very good way to split up a complex dialog. An
    alternative is to use a **QStackedWidget**  for which you provide some means
    of navigating between pages, for example, a **QToolBar**  or a
    **QListWidget** .

    Most of the functionality in QTabWidget is provided by a **QTabBar**  (at
    the top, providing the tabs) and a **QStackedWidget**  (most of the area,
    organizing the individual pages).

    **See also** **QTabBar** , **QStackedWidget** , **QToolBox** , and **Tab
    Dialog Example** .
    """

    class TabShape(enum.Enum):
        Rounded: QTabWidget = ...
        Triangular: QTabWidget = ...

    class TabPosition(enum.Enum):
        North: QTabWidget = ...
        South: QTabWidget = ...
        West: QTabWidget = ...
        East: QTabWidget = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#QTabWidget

        **QTabWidget::QTabWidget(QWidget * parent = nullptr)**

        Constructs a tabbed widget with parent **parent**.
        """
        ...

    def setTabVisible(self, index: int, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabVisible

        **[since 5.15] void QTabWidget::setTabVisible(int index , bool visible
        )**

        If **visible** is true, the page at position **index** is visible;
        otherwise the page at position **index** is hidden. The page's tab is
        redrawn appropriately.

        This function was introduced in Qt 5.15.

        **See also** **isTabVisible** ().
        """
        ...

    def isTabVisible(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#isTabVisible

        **[since 5.15] bool QTabWidget::isTabVisible(int index ) const**

        Returns true if the page at position **index** is visible; otherwise
        returns false.

        This function was introduced in Qt 5.15.

        **See also** **setTabVisible** ().
        """
        ...

    def setTabBarAutoHide(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabBarAutoHide-prop

        **[since 5.4] tabBarAutoHide : bool**

        If true, the tab bar is automatically hidden when it contains less than
        2 tabs.

        By default, this property is false.

        This property was introduced in Qt 5.4.

        **Access functions:**

        bool **tabBarAutoHide** () const
        void **setTabBarAutoHide** (bool
        **enabled** )

        **See also** **QWidget::visible** .
        """
        ...

    def tabBarAutoHide(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabBarAutoHide-prop

        **[since 5.4] tabBarAutoHide : bool**

        If true, the tab bar is automatically hidden when it contains less than
        2 tabs.

        By default, this property is false.

        This property was introduced in Qt 5.4.

        **Access functions:**

        bool **tabBarAutoHide** () const
        void **setTabBarAutoHide** (bool
        **enabled** )

        **See also** **QWidget::visible** .
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#hasHeightForWidth

        **[override virtual] bool QTabWidget::hasHeightForWidth() const**

        Reimplements: **QWidget::hasHeightForWidth() const** .
        """
        ...

    def heightForWidth(self, width: int) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#heightForWidth

        **[override virtual] int QTabWidget::heightForWidth(int width ) const**

        Reimplements: **QWidget::heightForWidth(int w) const** .
        """
        ...

    def setDocumentMode(self, set: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#documentMode-prop

        **documentMode : bool**

        This property holds whether or not the tab widget is rendered in a mode
        suitable for document pages. This is the same as document mode on macOS.

        When this property is set the tab widget frame is not rendered. This
        mode is useful for showing document-type pages where the page covers
        most of the tab widget area.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool **set**
        )

        **See also** **elideMode** , **QTabBar::documentMode** ,
        **QTabBar::usesScrollButtons** , and
        **QStyle::SH_TabBar_PreferNoArrows** .
        """
        ...

    def documentMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#documentMode-prop

        **documentMode : bool**

        This property holds whether or not the tab widget is rendered in a mode
        suitable for document pages. This is the same as document mode on macOS.

        When this property is set the tab widget frame is not rendered. This
        mode is useful for showing document-type pages where the page covers
        most of the tab widget area.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool **set**
        )

        **See also** **elideMode** , **QTabBar::documentMode** ,
        **QTabBar::usesScrollButtons** , and
        **QStyle::SH_TabBar_PreferNoArrows** .
        """
        ...

    def setMovable(self, movable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#movable-prop

        **movable : bool**

        This property holds whether the user can move the tabs within the tabbar
        area.

        By default, this property is `false`;

        **Access functions:**

        bool **isMovable** () const
        void **setMovable** (bool **movable** )
        """
        ...

    def isMovable(self) -> bool:
        ...

    def setTabsClosable(self, closeable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabsClosable-prop

        **tabsClosable : bool**

        This property holds whether close buttons are automatically added to
        each tab.

        **Access functions:**

        bool **tabsClosable** () const
        void **setTabsClosable** (bool
        **closeable** )

        **See also** **QTabBar::tabsClosable** ().
        """
        ...

    def tabsClosable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabsClosable-prop

        **tabsClosable : bool**

        This property holds whether close buttons are automatically added to
        each tab.

        **Access functions:**

        bool **tabsClosable** () const
        void **setTabsClosable** (bool
        **closeable** )

        **See also** **QTabBar::tabsClosable** ().
        """
        ...

    def setUsesScrollButtons(self, useButtons: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#usesScrollButtons-prop

        **usesScrollButtons : bool**

        This property holds whether or not a tab bar should use buttons to
        scroll tabs when it has many tabs.

        When there are too many tabs in a tab bar for its size, the tab bar can
        either choose to expand its size or to add buttons that allow you to
        scroll through the tabs.

        By default the value is style dependent.

        **Access functions:**

        bool **usesScrollButtons** () const
        void **setUsesScrollButtons**
        (bool **useButtons** )

        **See also** **elideMode** , **QTabBar::usesScrollButtons** , and
        **QStyle::SH_TabBar_PreferNoArrows** .

        **Member Function Documentation**
        """
        ...

    def usesScrollButtons(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#usesScrollButtons-prop

        **usesScrollButtons : bool**

        This property holds whether or not a tab bar should use buttons to
        scroll tabs when it has many tabs.

        When there are too many tabs in a tab bar for its size, the tab bar can
        either choose to expand its size or to add buttons that allow you to
        scroll through the tabs.

        By default the value is style dependent.

        **Access functions:**

        bool **usesScrollButtons** () const
        void **setUsesScrollButtons**
        (bool **useButtons** )

        **See also** **elideMode** , **QTabBar::usesScrollButtons** , and
        **QStyle::SH_TabBar_PreferNoArrows** .

        **Member Function Documentation**
        """
        ...

    def setIconSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size for icons in the tab bar

        The default value is style-dependent. This is the maximum size that the
        icons will have. Icons are not scaled up if they are of smaller size.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )

        **See also** **QTabBar::iconSize** .
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size for icons in the tab bar

        The default value is style-dependent. This is the maximum size that the
        icons will have. Icons are not scaled up if they are of smaller size.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )

        **See also** **QTabBar::iconSize** .
        """
        ...

    def setElideMode(self, a0: QtCore.Qt.TextElideMode) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#elideMode-prop

        **elideMode : Qt::TextElideMode**

        how to elide text in the tab bar

        This property controls how items are elided when there is not enough
        space to show them for a given tab bar size.

        By default the value is style dependent.

        **Access functions:**

        Qt::TextElideMode **elideMode** () const
        void **setElideMode**
        (Qt::TextElideMode **mode** )

        **See also** **QTabBar::elideMode** , **usesScrollButtons** , and
        **QStyle::SH_TabBar_ElideMode** .
        """
        ...

    def elideMode(self) -> QtCore.Qt.TextElideMode:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#elideMode-prop

        **elideMode : Qt::TextElideMode**

        how to elide text in the tab bar

        This property controls how items are elided when there is not enough
        space to show them for a given tab bar size.

        By default the value is style dependent.

        **Access functions:**

        Qt::TextElideMode **elideMode** () const
        void **setElideMode**
        (Qt::TextElideMode **mode** )

        **See also** **QTabBar::elideMode** , **usesScrollButtons** , and
        **QStyle::SH_TabBar_ElideMode** .
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#changeEvent

        **[override virtual protected] void QTabWidget::changeEvent(QEvent * ev
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def tabBar(self) -> QTabBar:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabBar

        **QTabBar *QTabWidget::tabBar() const**

        Returns the current **QTabBar** .

        **See also** **setTabBar** ().
        """
        ...

    def setTabBar(self, a0: QTabBar) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabBar

        **[protected] void QTabWidget::setTabBar(QTabBar * tb )**

        Replaces the dialog's **QTabBar**  heading with the tab bar **tb**. Note
        that this must be called **before** any tabs have been added, or the
        behavior is undefined.

        **See also** **tabBar** ().
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#paintEvent

        **[override virtual protected] void QTabWidget::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).

        Paints the tab widget's tab bar in response to the paint **event**.
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#keyPressEvent

        **[override virtual protected] void QTabWidget::keyPressEvent(QKeyEvent
        * e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#resizeEvent

        **[override virtual protected] void QTabWidget::resizeEvent(QResizeEvent
        * e )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#showEvent

        **[override virtual protected] void QTabWidget::showEvent(QShowEvent
        *)**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#event

        **[override virtual protected] bool QTabWidget::event(QEvent * ev )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def tabRemoved(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabRemoved

        **[virtual protected] void QTabWidget::tabRemoved(int index )**

        This virtual handler is called after a tab was removed from position
        **index**.

        **See also** **tabInserted** ().
        """
        ...

    def tabInserted(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabInserted

        **[virtual protected] void QTabWidget::tabInserted(int index )**

        This virtual handler is called after a new tab was added or inserted at
        position **index**.

        **See also** **tabRemoved** ().
        """
        ...

    def initStyleOption(self, option: QStyleOptionTabWidgetFrame) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#initStyleOption

        **[virtual protected] void
        QTabWidget::initStyleOption(QStyleOptionTabWidgetFrame * option )
        const**

        Initialize **option** with the values from this **QTabWidget** . This
        method is useful for subclasses when they need a
        **QStyleOptionTabWidgetFrame** , but don't want to fill in all the
        information themselves.

        **See also** **QStyleOption::initFrom** () and
        **QTabBar::initStyleOption** ().
        """
        ...

    def setCurrentWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setCurrentWidget

        **[slot] void QTabWidget::setCurrentWidget(QWidget * widget )**

        Makes **widget** the current widget. The **widget** used must be a page
        in this tab widget.

        **See also** **addTab** (), **setCurrentIndex** (), and
        **currentWidget** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index position of the current tab page

        The current index is -1 if there is no current widget.

        By default, this property contains a value of -1 because there are
        initially no tabs in the widget.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )
        """
        ...

    def cornerWidget(self, corner: QtCore.Qt.Corner = ...) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#cornerWidget

        **QWidget *QTabWidget::cornerWidget(Qt::Corner corner =
        Qt::TopRightCorner) const**

        Returns the widget shown in the **corner** of the tab widget or
        `nullptr`.

        **See also** **setCornerWidget** ().
        """
        ...

    def setCornerWidget(self, widget: QWidget, corner: QtCore.Qt.Corner = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setCornerWidget

        **void QTabWidget::setCornerWidget(QWidget * widget , Qt::Corner corner
        = Qt::TopRightCorner)**

        Sets the given **widget** to be shown in the specified **corner** of the
        tab widget. The geometry of the widget is determined based on the
        widget's **sizeHint** () and the **style** ().

        Only the horizontal element of the **corner** will be used.

        Passing `nullptr` shows no widget in the corner.

        Any previously set corner widget is hidden.

        All widgets set here will be deleted by the tab widget when it is
        destroyed unless you separately reparent the widget after setting some
        other corner widget (or `nullptr`).

        Note: Corner widgets are designed for **North**  and **South**  tab
        positions; other orientations are known to not work properly.

        **See also** **cornerWidget** () and **setTabPosition** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#minimumSizeHint

        **[override virtual] QSize QTabWidget::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .

        Returns a suitable minimum size for the tab widget.
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#sizeHint

        **[override virtual] QSize QTabWidget::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def setTabShape(self, s: "QTabWidget.TabShape") -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabShape-prop

        **tabShape : TabShape**

        This property holds the shape of the tabs in this tab widget

        Possible values for this property are **QTabWidget::Rounded**  (default)
        or **QTabWidget::Triangular** .

        **Access functions:**

        QTabWidget::TabShape **tabShape** () const
        void **setTabShape**
        (QTabWidget::TabShape **s** )

        **See also** **TabShape** .
        """
        ...

    def tabShape(self) -> "QTabWidget.TabShape":
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabShape-prop

        **tabShape : TabShape**

        This property holds the shape of the tabs in this tab widget

        Possible values for this property are **QTabWidget::Rounded**  (default)
        or **QTabWidget::Triangular** .

        **Access functions:**

        QTabWidget::TabShape **tabShape** () const
        void **setTabShape**
        (QTabWidget::TabShape **s** )

        **See also** **TabShape** .
        """
        ...

    def setTabPosition(self, a0: "QTabWidget.TabPosition") -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabPosition-prop

        **tabPosition : TabPosition**

        This property holds the position of the tabs in this tab widget

        Possible values for this property are described by the **TabPosition**
        enum.

        By default, this property is set to **North** .

        **Access functions:**

        QTabWidget::TabPosition **tabPosition** () const
        void
        **setTabPosition** (QTabWidget::TabPosition **position** )

        **See also** **TabPosition** .
        """
        ...

    def tabPosition(self) -> "QTabWidget.TabPosition":
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabPosition-prop

        **tabPosition : TabPosition**

        This property holds the position of the tabs in this tab widget

        Possible values for this property are described by the **TabPosition**
        enum.

        By default, this property is set to **North** .

        **Access functions:**

        QTabWidget::TabPosition **tabPosition** () const
        void
        **setTabPosition** (QTabWidget::TabPosition **position** )

        **See also** **TabPosition** .
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#count-prop

        **[read-only] count : const int**

        This property holds the number of tabs in the tab bar

        By default, this property contains a value of 0.

        **Access functions:**

        int **count** () const
        """
        ...

    def indexOf(self, widget: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#indexOf

        **int QTabWidget::indexOf(const QWidget * w ) const**

        Returns the index position of the page occupied by the widget **w** , or
        -1 if the widget cannot be found.
        """
        ...

    def widget(self, index: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#widget

        **QWidget *QTabWidget::widget(int index ) const**

        Returns the tab page at index position **index** or `nullptr` if the
        **index** is out of range.
        """
        ...

    def currentWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#currentWidget

        **QWidget *QTabWidget::currentWidget() const**

        Returns a pointer to the page currently being displayed by the tab
        dialog. The tab dialog does its best to make sure that this value is
        never 0 (but if you try hard enough, it can be).

        **See also** **currentIndex** () and **setCurrentWidget** ().
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index position of the current tab page

        The current index is -1 if there is no current widget.

        By default, this property contains a value of -1 because there are
        initially no tabs in the widget.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )
        """
        ...

    def tabWhatsThis(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabWhatsThis

        **QString QTabWidget::tabWhatsThis(int index ) const**

        Returns the What's This help text for the page at position **index** ,
        or an empty string if no help text has been set.

        **See also** **setTabWhatsThis** ().
        """
        ...

    def setTabWhatsThis(self, index: int, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabWhatsThis

        **void QTabWidget::setTabWhatsThis(int index , const QString & text )**

        Sets the What's This help text for the page at position **index** to
        **text**.

        **See also** **tabWhatsThis** ().
        """
        ...

    def tabToolTip(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabToolTip

        **QString QTabWidget::tabToolTip(int index ) const**

        Returns the tab tool tip for the page at position **index** or an empty
        string if no tool tip has been set.

        **See also** **setTabToolTip** ().
        """
        ...

    def setTabToolTip(self, index: int, tip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabToolTip

        **void QTabWidget::setTabToolTip(int index , const QString & tip )**

        Sets the tab tool tip for the page at position **index** to **tip**.

        **See also** **tabToolTip** ().
        """
        ...

    def setTabIcon(self, index: int, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabIcon

        **void QTabWidget::setTabIcon(int index , const QIcon & icon )**

        Sets the **icon** for the tab at position **index**.

        **See also** **tabIcon** ().
        """
        ...

    def tabIcon(self, index: int) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabIcon

        **QIcon QTabWidget::tabIcon(int index ) const**

        Returns the icon for the tab on the page at position **index**.

        **See also** **setTabIcon** ().
        """
        ...

    def setTabText(self, index: int, a1: str) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabText

        **void QTabWidget::setTabText(int index , const QString & label )**

        Defines a new **label** for the page at position **index** 's tab.

        If the provided text contains an ampersand character ('&'), a shortcut
        is automatically created for it. The character that follows the '&' will
        be used as the shortcut key. Any previous shortcut will be overwritten,
        or cleared if no shortcut is defined by the text. See the **QShortcut**
        documentation for details (to display an actual ampersand, use '&&').

        **See also** **tabText** ().
        """
        ...

    def tabText(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabText

        **QString QTabWidget::tabText(int index ) const**

        Returns the label text for the tab on the page at position **index**.

        **See also** **setTabText** ().
        """
        ...

    def setTabEnabled(self, index: int, a1: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#setTabEnabled

        **void QTabWidget::setTabEnabled(int index , bool enable )**

        If **enable** is true, the page at position **index** is enabled;
        otherwise the page at position **index** is disabled. The page's tab is
        redrawn appropriately.

        **QTabWidget**  uses **QWidget::setEnabled** () internally, rather than
        keeping a separate flag.

        Note that even a disabled tab/page may be visible. If the page is
        visible already, **QTabWidget**  will not hide it; if all the pages are
        disabled, **QTabWidget**  will show one of them.

        **See also** **isTabEnabled** () and **QWidget::setEnabled** ().
        """
        ...

    def isTabEnabled(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#isTabEnabled

        **bool QTabWidget::isTabEnabled(int index ) const**

        Returns `true` if the page at position **index** is enabled; otherwise
        returns `false`.

        **See also** **setTabEnabled** () and **QWidget::isEnabled** ().
        """
        ...

    def removeTab(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#removeTab

        **void QTabWidget::removeTab(int index )**

        Removes the tab at position **index** from this stack of widgets. The
        page widget itself is not deleted.

        **See also** **addTab** () and **insertTab** ().
        """
        ...

    @typing.overload
    def insertTab(self, index: int, widget: QWidget, a2: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#insertTab

        **int QTabWidget::insertTab(int index , QWidget * page , const QString &
        label )**

        Inserts a tab with the given **label** and **page** into the tab widget
        at the specified **index** , and returns the index of the inserted tab
        in the tab bar. Ownership of **page** is passed on to the **QTabWidget**
        .

        The label is displayed in the tab and may vary in appearance depending
        on the configuration of the tab widget.

        If the tab's **label** contains an ampersand, the letter following the
        ampersand is used as a shortcut for the tab, e.g. if the label is
        "Bro&wse" then Alt+W becomes a shortcut which will move the focus to
        this tab.

        If **index** is out of range, the tab is simply appended. Otherwise it
        is inserted at the specified position.

        If the **QTabWidget**  was empty before this function is called, the new
        page becomes the current page. Inserting a new tab at an index less than
        or equal to the current index will increment the current index, but keep
        the current page.

        **Note:** If you call insertTab() after **show** (), the layout system
        will try to adjust to the changes in its widgets hierarchy and may cause
        flicker. To prevent this, you can set the **QWidget::updatesEnabled**
        property to false prior to changes; remember to set the property to true
        when the changes are done, making the widget receive paint events again.

        **See also** **addTab** ().
        """
        ...

    @typing.overload
    def insertTab(
        self, index: int, widget: QWidget, icon: QtGui.QIcon, label: str
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#insertTab-1

        **int QTabWidget::insertTab(int index , QWidget * page , const QIcon &
        icon , const QString & label )**

        This is an overloaded function.

        Inserts a tab with the given **label** , **page** , and **icon** into
        the tab widget at the specified **index** , and returns the index of the
        inserted tab in the tab bar. Ownership of **page** is passed on to the
        **QTabWidget** .

        This function is the same as insertTab(), but with an additional
        **icon**.
        """
        ...

    @typing.overload
    def addTab(self, widget: QWidget, a1: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#addTab

        **int QTabWidget::addTab(QWidget * page , const QString & label )**

        Adds a tab with the given **page** and **label** to the tab widget, and
        returns the index of the tab in the tab bar. Ownership of **page** is
        passed on to the **QTabWidget** .

        If the tab's **label** contains an ampersand, the letter following the
        ampersand is used as a shortcut for the tab, e.g. if the label is
        "Bro&wse" then Alt+W becomes a shortcut which will move the focus to
        this tab.

        **Note:** If you call addTab() after **show** (), the layout system will
        try to adjust to the changes in its widgets hierarchy and may cause
        flicker. To prevent this, you can set the **QWidget::updatesEnabled**
        property to false prior to changes; remember to set the property to true
        when the changes are done, making the widget receive paint events again.

        **See also** **insertTab** ().
        """
        ...

    @typing.overload
    def addTab(self, widget: QWidget, icon: QtGui.QIcon, label: str) -> int:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#addTab-1

        **int QTabWidget::addTab(QWidget * page , const QIcon & icon , const
        QString & label )**

        This is an overloaded function.

        Adds a tab with the given **page** , **icon** , and **label** to the tab
        widget, and returns the index of the tab in the tab bar. Ownership of
        **page** is passed on to the **QTabWidget** .

        This function is the same as addTab(), but with an additional **icon**.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#clear

        **void QTabWidget::clear()**

        Removes all the pages, but does not delete them. Calling this function
        is equivalent to calling **removeTab** () until the tab widget is empty.
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#currentChanged

        **[signal] void QTabWidget::currentChanged(int index )**

        This signal is emitted whenever the current page index changes. The
        parameter is the new current page **index** position, or -1 if there
        isn't a new one (for example, if there are no widgets in the
        **QTabWidget** )

        **Note:** Notifier signal for property **currentIndex** .

        **See also** **currentWidget** () and **currentIndex** .
        """
        ...

    @property
    def tabBarClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabBarClicked

        **[signal, since 5.2] void QTabWidget::tabBarClicked(int index )**

        This signal is emitted when user clicks on a tab at an **index**.

        **index** refers to the tab clicked, or -1 if no tab is under the
        cursor.

        This function was introduced in Qt 5.2.
        """
        ...

    @property
    def tabBarDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabBarDoubleClicked

        **[signal, since 5.2] void QTabWidget::tabBarDoubleClicked(int index )**

        This signal is emitted when the user double clicks on a tab at an
        **index**.

        **index** is the index of a clicked tab, or -1 if no tab is under the
        cursor.

        This function was introduced in Qt 5.2.
        """
        ...

    @property
    def tabCloseRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtabwidget.html#tabCloseRequested

        **[signal] void QTabWidget::tabCloseRequested(int index )**

        This signal is emitted when the close button on a tab is clicked. The
        **index** is the index that should be removed.

        **See also** **setTabsClosable** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QMediaPlayer(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qmediaplayer.html

    **Detailed Description**

    The QMediaPlayer class is a high level media playback class. It can be used
    to playback audio of video media files. The content to playback is specified
    as a **QUrl**  object.

    player = new **QMediaPlayer** ;
        audioOutput = new **QAudioOutput** ;
    player->setAudioOutput(audioOutput);
        connect(player,
    SIGNAL(positionChanged(**qint64** )), this, SLOT(positionChanged(**qint64**
    )));
        player->setSource(**QUrl**
    ::fromLocalFile("/Users/me/Music/coolsong.mp3"));
    audioOutput->setVolume(50);
        player->play();

    **QVideoWidget**  can be used with QMediaPlayer for video rendering.

    **See also** **QVideoWidget** .
    """

    class Loops(enum.IntEnum):
        Infinite: QMediaPlayer = ...
        Once: QMediaPlayer = ...

    class Error(enum.Enum):
        NoError: QMediaPlayer = ...
        ResourceError: QMediaPlayer = ...
        FormatError: QMediaPlayer = ...
        NetworkError: QMediaPlayer = ...
        AccessDeniedError: QMediaPlayer = ...

    class MediaStatus(enum.Enum):
        NoMedia: QMediaPlayer = ...
        LoadingMedia: QMediaPlayer = ...
        LoadedMedia: QMediaPlayer = ...
        StalledMedia: QMediaPlayer = ...
        BufferingMedia: QMediaPlayer = ...
        BufferedMedia: QMediaPlayer = ...
        EndOfMedia: QMediaPlayer = ...
        InvalidMedia: QMediaPlayer = ...

    class PlaybackState(enum.Enum):
        StoppedState: QMediaPlayer = ...
        PlayingState: QMediaPlayer = ...
        PausedState: QMediaPlayer = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#QMediaPlayer

        **QMediaPlayer::QMediaPlayer(QObject * parent = nullptr)**

        Constructs a QMediaPlayer instance as a child of **parent**.
        """
        ...

    def setLoops(self, loops: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#loops-prop

        **loops : int**

        Determines how often the media is played before the player stops. Set to
        **QMediaPlayer::Infinite**  to loop the current media file forever.

        The default value is `1`. Setting this property to `0` has no effect.

        **Access functions:**

        int **loops** () const
        void **setLoops** (int **loops** )

        **Notifier signal:**

        void **loopsChanged** ()
        """
        ...

    def loops(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#loops-prop

        **loops : int**

        Determines how often the media is played before the player stops. Set to
        **QMediaPlayer::Infinite**  to loop the current media file forever.

        The default value is `1`. Setting this property to `0` has no effect.

        **Access functions:**

        int **loops** () const
        void **setLoops** (int **loops** )

        **Notifier signal:**

        void **loopsChanged** ()
        """
        ...

    def errorChanged(self) -> None:
        ...

    def activeTracksChanged(self) -> None:
        ...

    def tracksChanged(self) -> None:
        ...

    def metaDataChanged(self) -> None:
        ...

    def setSourceDevice(
        self, device: QtCore.QIODevice, sourceUrl: QtCore.QUrl = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#setSourceDevice

        **[slot] void QMediaPlayer::setSourceDevice(QIODevice * device , const
        QUrl & sourceUrl = QUrl())**

        Sets the current source **device**.

        The media data will be read from **device**. The **sourceUrl** can be
        provided to resolve additional information about the media, mime type
        etc. The **device** must be open and readable.

        For macOS the **device** should also be seek-able.

        **Note:** This function returns immediately after recording the
        specified source of the media. It does not wait for the media to finish
        loading and does not check for errors. Listen for the
        **mediaStatusChanged** () and **error** () signals to be notified when
        the media is loaded, and if an error occurs during loading.

        **See also** **sourceDevice** ().
        """
        ...

    def setSource(self, source: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#setSource

        **[slot] void QMediaPlayer::setSource(const QUrl & source )**

        Sets the current **source**.

        Setting the media to a null **QUrl**  will cause the player to discard
        all information relating to the current media source and to cease all
        I/O operations related to that media.

        **Note:** This function returns immediately after recording the
        specified source of the media. It does not wait for the media to finish
        loading and does not check for errors. Listen for the
        **mediaStatusChanged** () and **error** () signals to be notified when
        the media is loaded and when an error occurs during loading.

        **Note:** Setter function for property **source** .

        **See also** **source** ().
        """
        ...

    def setPlaybackRate(self, rate: float) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#playbackRate

        **qreal QMediaPlayer::playbackRate() const**

        Returns the current playback rate.

        **Note:** Getter function for property playbackRate.

        **See also** **setPlaybackRate** ().
        """
        ...

    def setPosition(self, position: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#position

        **qint64 QMediaPlayer::position() const**

        Returns the current position inside the media being played back in ms.

        Returns 0 if the media player doesn't have a valid media file or stream.
        For live streams, the duration usually changes during playback as more
        data becomes available.

        **Note:** Getter function for property position.

        **See also** **setPosition** ().
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#stop

        **[slot] void QMediaPlayer::stop()**

        Stop playing, and reset the play position to the beginning.

        **See also** **play** () and **pause** ().
        """
        ...

    def pause(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#pause

        **[slot] void QMediaPlayer::pause()**

        Pause playing the current source.

        **See also** **play** () and **stop** ().
        """
        ...

    def play(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#play

        **[slot] void QMediaPlayer::play()**

        Start or resume playing the current source.

        **See also** **pause** () and **stop** ().
        """
        ...

    def metaData(self) -> QMediaMetaData:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#metaData

        **QMediaMetaData QMediaPlayer::metaData() const**

        Returns meta data for the current media used by the media player.

        Meta data can contain information such as the title of the video or its
        creation date.

        **Note:** The Windows implementation provides metadata only for media
        located on the local file system.

        **Note:** Getter function for property metaData.
        """
        ...

    def isAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#isAvailable

        **bool QMediaPlayer::isAvailable() const**

        Returns true if the media player is supported on this platform.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#errorString-prop

        **[read-only] errorString : const QString**

        This property holds a string describing the current error condition in
        more detail.

        **Access functions:**

        QString **errorString** () const

        **Notifier signal:**

        void ****errorChanged** ** ()
        """
        ...

    def error(self) -> "QMediaPlayer.Error":
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#error

        **QMediaPlayer::Error QMediaPlayer::error() const**

        Returns the current error state.

        **Note:** Getter function for property error.
        """
        ...

    def playbackRate(self) -> float:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#playbackRate-prop

        **playbackRate : qreal**

        This property holds the playback rate of the current media.

        This value is a multiplier applied to the media's standard play rate. By
        default this value is 1.0, indicating that the media is playing at the
        standard pace. Values higher than 1.0 will increase the rate of play.
        Values less than zero can be set and indicate the media should rewind at
        the multiplier of the standard pace.

        Not all playback services support change of the playback rate. It is
        framework defined as to the status and quality of audio and video while
        fast forwarding or rewinding.

        **Access functions:**

        qreal ****playbackRate** ** () const
        void **setPlaybackRate** (qreal
        **rate** )

        **Notifier signal:**

        void ****playbackRateChanged** ** (qreal **rate** )
        """
        ...

    def isSeekable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#isSeekable

        **bool QMediaPlayer::isSeekable() const**

        Returns true if the media is seekable. Most file based media files are
        seekable, but live streams usually are not.

        **Note:** Getter function for property **seekable** .

        **See also** **position** .
        """
        ...

    def bufferedTimeRange(self) -> "QMediaTimeRange":
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#bufferedTimeRange

        **QMediaTimeRange QMediaPlayer::bufferedTimeRange() const**

        Returns a **QMediaTimeRange**  describing the currently buffered data.

        When streaming media from a remote source, different parts of the media
        file can be available locally. The returned **QMediaTimeRange**  object
        describes the time ranges that are buffered and available for immediate
        playback.

        **See also** **QMediaTimeRange** .
        """
        ...

    def bufferProgress(self) -> float:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#bufferProgress

        **float QMediaPlayer::bufferProgress() const**

        Returns a number betwee 0 and 1 when buffering data.

        0 means that there is no buffered data available, playback is usually
        stalled in this case. Playback will resume once the buffer reaches 1,
        meaning enough data has been buffered to be able to resume playback.

        bufferProgress() will always return 1 for local files.

        **Note:** Getter function for property bufferProgress.
        """
        ...

    def hasVideo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#hasVideo-prop

        **[read-only] hasVideo : const bool**

        This property holds whether the media contains video.

        **Access functions:**

        bool **hasVideo** () const

        **Notifier signal:**

        void ****hasVideoChanged** ** (bool **videoAvailable** )
        """
        ...

    def hasAudio(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#hasAudio-prop

        **[read-only] hasAudio : const bool**

        This property holds whether the media contains audio.

        **Access functions:**

        bool **hasAudio** () const

        **Notifier signal:**

        void ****hasAudioChanged** ** (bool **available** )
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#position-prop

        **position : qint64**

        This property holds the playback position of the current media.

        The value is the current playback position, expressed in milliseconds
        since the beginning of the media. Periodically changes in the position
        will be indicated with the **positionChanged** () signal.

        If the **seekable**  property is true, this property can be set to
        milliseconds.

        **Access functions:**

        qint64 ****position** ** () const
        void **setPosition** (qint64
        **position** )

        **Notifier signal:**

        void ****positionChanged** ** (qint64 **position** )
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#duration

        **qint64 QMediaPlayer::duration() const**

        Returns the duration of the current media in ms.

        Returns 0 if the media player doesn't have a valid media file or stream.
        For live streams, the duration usually changes during playback as more
        data becomes available.

        **Note:** Getter function for property duration.
        """
        ...

    def mediaStatus(self) -> "QMediaPlayer.MediaStatus":
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#mediaStatus-prop

        **[read-only] mediaStatus : const MediaStatus**

        This property holds the status of the current media stream.

        The stream status describes how the playback of the current stream is
        progressing.

        By default this property is **QMediaPlayer::NoMedia**

        **Access functions:**

        QMediaPlayer::MediaStatus **mediaStatus** () const

        **Notifier signal:**

        void ****mediaStatusChanged** ** (QMediaPlayer::MediaStatus **status** )
        """
        ...

    def playbackState(self) -> "QMediaPlayer.PlaybackState":
        ...

    def sourceDevice(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#sourceDevice

        **const QIODevice *QMediaPlayer::sourceDevice() const**

        Returns the stream source of media data.

        This is only valid if a stream was passed to **setSource** ().

        **See also** **setSourceDevice** () and **setSource** ().
        """
        ...

    def source(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#source-prop

        **source : QUrl**

        This property holds the active media source being used by the player
        object.

        The player object will use the **QUrl**  for selection of the content to
        be played.

        By default this property has a null **QUrl** .

        Setting this property to a null **QUrl**  will cause the player to
        discard all information relating to the current media source and to
        cease all I/O operations related to that media.

        **Access functions:**

        QUrl **source** () const
        void ****setSource** ** (const QUrl &
        **source** )

        **Notifier signal:**

        void ****sourceChanged** ** (const QUrl & **media** )

        **See also** **QUrl** .
        """
        ...

    def videoSink(self) -> "QVideoSink":
        ...

    def setVideoSink(self, sink: "QVideoSink") -> None:
        ...

    def videoOutput(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#videoOutput-prop

        **videoOutput : QObject***

        This property holds the video output to be used by the media player.

        A media player can only have one video output attached, so setting this
        property will replace the previously connected video output.

        Setting this property to `nullptr` will disable video output.

        **Access functions:**

        QObject * **videoOutput** () const
        void **setVideoOutput** (QObject *)

        **Notifier signal:**

        void **videoOutputChanged** ()

        **Member Function Documentation**
        """
        ...

    def setVideoOutput(self, a0: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#videoOutput-prop

        **videoOutput : QObject***

        This property holds the video output to be used by the media player.

        A media player can only have one video output attached, so setting this
        property will replace the previously connected video output.

        Setting this property to `nullptr` will disable video output.

        **Access functions:**

        QObject * **videoOutput** () const
        void **setVideoOutput** (QObject *)

        **Notifier signal:**

        void **videoOutputChanged** ()

        **Member Function Documentation**
        """
        ...

    def audioOutput(self) -> QAudioOutput:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#audioOutput-prop

        **audioOutput : QAudioOutput***

        This property holds the audio output device used by the media player.

        The current audio output to be used when playing back media. Setting a
        new audio output will replace the currently used output.

        Setting this property to `nullptr` will disable any audio output.

        **Access functions:**

        QAudioOutput * **audioOutput** () const
        void **setAudioOutput**
        (QAudioOutput * **output** )

        **Notifier signal:**

        void **audioOutputChanged** ()
        """
        ...

    def setAudioOutput(self, output: QAudioOutput) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#audioOutput-prop

        **audioOutput : QAudioOutput***

        This property holds the audio output device used by the media player.

        The current audio output to be used when playing back media. Setting a
        new audio output will replace the currently used output.

        Setting this property to `nullptr` will disable any audio output.

        **Access functions:**

        QAudioOutput * **audioOutput** () const
        void **setAudioOutput**
        (QAudioOutput * **output** )

        **Notifier signal:**

        void **audioOutputChanged** ()
        """
        ...

    def setActiveSubtitleTrack(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#activeSubtitleTrack-prop

        **activeSubtitleTrack : int**

        Returns the currently active subtitle track.

        Set **index** to `-1` to disable subtitles.

        Subtitles are disabled by default.

        **Access functions:**

        int **activeSubtitleTrack** () const
        void **setActiveSubtitleTrack**
        (int **index** )

        **Notifier signal:**

        void ****activeTracksChanged** ** ()
        """
        ...

    def setActiveVideoTrack(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#activeVideoTrack-prop

        **activeVideoTrack : int**

        Returns the currently active video track.

        By default, the first available audio track will be chosen.

        Set **index** to `-1` to disable all video tracks.

        **Access functions:**

        int **activeVideoTrack** () const
        void **setActiveVideoTrack** (int
        **index** )

        **Notifier signal:**

        void ****activeTracksChanged** ** ()
        """
        ...

    def setActiveAudioTrack(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#activeAudioTrack-prop

        **activeAudioTrack : int**

        Returns the currently active audio track.

        By default, the first available audio track will be chosen.

        Set **index** to `-1` to disable all audio tracks.

        **Access functions:**

        int **activeAudioTrack** () const
        void **setActiveAudioTrack** (int
        **index** )

        **Notifier signal:**

        void ****activeTracksChanged** ** ()
        """
        ...

    def activeSubtitleTrack(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#activeSubtitleTrack-prop

        **activeSubtitleTrack : int**

        Returns the currently active subtitle track.

        Set **index** to `-1` to disable subtitles.

        Subtitles are disabled by default.

        **Access functions:**

        int **activeSubtitleTrack** () const
        void **setActiveSubtitleTrack**
        (int **index** )

        **Notifier signal:**

        void ****activeTracksChanged** ** ()
        """
        ...

    def activeVideoTrack(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#activeVideoTrack-prop

        **activeVideoTrack : int**

        Returns the currently active video track.

        By default, the first available audio track will be chosen.

        Set **index** to `-1` to disable all video tracks.

        **Access functions:**

        int **activeVideoTrack** () const
        void **setActiveVideoTrack** (int
        **index** )

        **Notifier signal:**

        void ****activeTracksChanged** ** ()
        """
        ...

    def activeAudioTrack(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#activeAudioTrack-prop

        **activeAudioTrack : int**

        Returns the currently active audio track.

        By default, the first available audio track will be chosen.

        Set **index** to `-1` to disable all audio tracks.

        **Access functions:**

        int **activeAudioTrack** () const
        void **setActiveAudioTrack** (int
        **index** )

        **Notifier signal:**

        void ****activeTracksChanged** ** ()
        """
        ...

    def subtitleTracks(self) -> typing.List[QMediaMetaData]:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#subtitleTracks

        **QList<QMediaMetaData> QMediaPlayer::subtitleTracks() const**

        Lists the set of available subtitle tracks inside the media.

        The **QMediaMetaData**  returned describes the properties of individual
        tracks.

        **Note:** Getter function for property subtitleTracks.
        """
        ...

    def videoTracks(self) -> typing.List[QMediaMetaData]:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#videoTracks

        **QList<QMediaMetaData> QMediaPlayer::videoTracks() const**

        Lists the set of available video tracks inside the media.

        The **QMediaMetaData**  returned describes the properties of individual
        tracks.

        **Note:** Getter function for property videoTracks.
        """
        ...

    def audioTracks(self) -> typing.List[QMediaMetaData]:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#audioTracks

        **QList<QMediaMetaData> QMediaPlayer::audioTracks() const**

        Lists the set of available audio tracks inside the media.

        The **QMediaMetaData**  returned describes the properties of individual
        tracks.

        Different audio tracks can for example contain audio in different
        languages.

        **Note:** Getter function for property audioTracks.
        """
        ...

    @property
    def audioOutputChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def bufferProgressChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#bufferProgressChanged

        **[signal] void QMediaPlayer::bufferProgressChanged(float filled )**

        Signals the amount of the local buffer **filled** as a number between 0
        and 1.

        **Note:** Notifier signal for property **bufferProgress** .
        """
        ...

    @property
    def durationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#durationChanged

        **[signal] void QMediaPlayer::durationChanged(qint64 duration )**

        Signals the duration of the content has changed to **duration** ,
        expressed in milliseconds.

        **Note:** Notifier signal for property **duration** .
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#errorOccurred

        **[signal] void QMediaPlayer::errorOccurred(QMediaPlayer::Error error ,
        const QString & errorString )**

        Signals that an **error** condition has occurred, with **errorString**
        containing a description of the error.

        **See also** **errorString** ().
        """
        ...

    @property
    def hasAudioChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#hasAudioChanged

        **[signal] void QMediaPlayer::hasAudioChanged(bool available )**

        Signals the availability of audio content has changed to **available**.

        **Note:** Notifier signal for property **hasAudio** .
        """
        ...

    @property
    def hasVideoChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#hasVideoChanged

        **[signal] void QMediaPlayer::hasVideoChanged(bool videoAvailable )**

        Signals the availability of visual content has changed to
        **videoAvailable**.

        **Note:** Notifier signal for property **hasVideo** .
        """
        ...

    @property
    def loopsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def mediaStatusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#mediaStatusChanged

        **[signal] void
        QMediaPlayer::mediaStatusChanged(QMediaPlayer::MediaStatus status )**

        Signals that the **status** of the current media has changed.

        **Note:** Notifier signal for property **mediaStatus** .

        **See also** **mediaStatus** ().
        """
        ...

    @property
    def playbackRateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#playbackRateChanged

        **[signal] void QMediaPlayer::playbackRateChanged(qreal rate )**

        Signals the **playbackRate**  has changed to **rate**.

        **Note:** Notifier signal for property **playbackRate** .
        """
        ...

    @property
    def playbackStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def positionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#positionChanged

        **[signal] void QMediaPlayer::positionChanged(qint64 position )**

        Signals the position of the content has changed to **position** ,
        expressed in milliseconds.

        **Note:** Notifier signal for property **position** .
        """
        ...

    @property
    def seekableChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#seekableChanged

        **[signal] void QMediaPlayer::seekableChanged(bool seekable )**

        Signals the **seekable** status of the player object has changed.

        **Note:** Notifier signal for property **seekable** .
        """
        ...

    @property
    def sourceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediaplayer.html#sourceChanged

        **[signal] void QMediaPlayer::sourceChanged(const QUrl & media )**

        Signals that the media source has been changed to **media**.

        **Note:** Notifier signal for property **source** .
        """
        ...

    @property
    def videoOutputChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSql import *
import enum


class QSqlField(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsqlfield.html

    **Detailed Description**

    QSqlField represents the characteristics of a single column in a database
    table or view, such as the data type and column name. A field also contains
    the value of the database column, which can be viewed or changed.

    Field data values are stored as QVariants. Using an incompatible type is not
    permitted. For example:

    **QSqlField**  field("age", **QMetaType** ::fromType<int>());
    field.setValue(QPixmap());  // WRONG

    However, the field will attempt to cast certain data types to the field data
    type where possible:

    **QSqlField**  field("age", **QMetaType** ::fromType<int>());
    field.setValue(**QString** ("123"));  // casts QString to int

    QSqlField objects are rarely created explicitly in application code. They
    are usually accessed indirectly through **QSqlRecord** s that already
    contain a list of fields. For example:

    **QSqlQuery**  query;
            ...
            **QSqlRecord**  record =
    query.record();
            **QSqlField**  field = record.field("country");

    A QSqlField object can provide some meta-data about the field, for example,
    its **name** (), variant type(), **length** (), **precision** (),
    **defaultValue** (), typeID(), and its **requiredStatus** (),
    **isGenerated** () and **isReadOnly** (). The field's data can be checked to
    see if it **isNull** (), and its **value** () retrieved. When editing the
    data can be set with **setValue** () or set to NULL with **clear** ().

    **See also** **QSqlRecord** .
    """

    class RequiredStatus(enum.Enum):
        Unknown: QSqlField = ...
        Optional: QSqlField = ...
        Required: QSqlField = ...

    @typing.overload
    def __init__(
        self, fieldName: str = ..., type: QtCore.QMetaType = ..., tableName: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#QSqlField

        **QSqlField::QSqlField(const QSqlField & other )**

        Constructs a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSqlField") -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#QSqlField-1

        **[since 6.0] QSqlField::QSqlField(const QString & fieldName =
        QString(), QMetaType type = QMetaType(), const QString & table =
        QString())**

        This is an overloaded function.

        Constructs an empty field called **fieldName** of type **type** in
        **table**.

        This function was introduced in Qt 6.0.

        **See also** **setRequiredStatus** (), **setLength** (),
        **setPrecision** (), **setDefaultValue** (), **setGenerated** (), and
        **setReadOnly** ().
        """
        ...

    def setMetaType(self, type: QtCore.QMetaType) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setMetaType

        **void QSqlField::setMetaType(QMetaType type )**

        Set's the field's variant type to **type**.

        **See also** **metaType** (), **setRequiredStatus** (), **setLength**
        (), **setPrecision** (), **setDefaultValue** (), **setGenerated** (),
        and **setReadOnly** ().
        """
        ...

    def metaType(self) -> QtCore.QMetaType:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#metaType

        **QMetaType QSqlField::metaType() const**

        Returns the field's type as stored in the database. Note that the actual
        value might have a different type, Numerical values that are too large
        to store in a long int or double are usually stored as strings to
        prevent precision loss.

        **See also** **setMetaType** ().
        """
        ...

    def tableName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#tableName

        **QString QSqlField::tableName() const**

        Returns the tableName of the field.

        **Note:** When using the QPSQL driver, due to limitations in the libpq
        library, the `tableName()` field is not populated in a **QSqlField**
        resulting from a **QSqlRecord**  obtained by **QSqlQuery::record** () of
        a forward-only query.

        **See also** **setTableName** ().
        """
        ...

    def setTableName(self, tableName: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setTableName

        **void QSqlField::setTableName(const QString & table )**

        Sets the **tableName**  of the field to **table**.

        **See also** **tableName** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#isValid

        **bool QSqlField::isValid() const**

        Returns `true` if the field's variant type is valid; otherwise returns
        `false`.
        """
        ...

    def isGenerated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#isGenerated

        **bool QSqlField::isGenerated() const**

        Returns `true` if the field is generated; otherwise returns false.

        **See also** **setGenerated** (), **metaType** (), **requiredStatus**
        (), **length** (), **precision** (), and **defaultValue** ().
        """
        ...

    def typeID(self) -> int:
        ...

    def defaultValue(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#defaultValue

        **QVariant QSqlField::defaultValue() const**

        Returns the field's default value (which may be NULL).

        **See also** **setDefaultValue** (), **metaType** (), **requiredStatus**
        (), **length** (), **precision** (), and **isGenerated** ().
        """
        ...

    def precision(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#precision

        **int QSqlField::precision() const**

        Returns the field's precision; this is only meaningful for numeric
        types.

        If the returned value is negative, it means that the information is not
        available from the database.

        **See also** **setPrecision** (), **metaType** (), **requiredStatus**
        (), **length** (), **defaultValue** (), and **isGenerated** ().
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#length

        **int QSqlField::length() const**

        Returns the field's length.

        If the returned value is negative, it means that the information is not
        available from the database.

        **See also** **setLength** (), **metaType** (), **requiredStatus** (),
        **precision** (), **defaultValue** (), and **isGenerated** ().
        """
        ...

    def requiredStatus(self) -> "QSqlField.RequiredStatus":
        """
        https://doc.qt.io/qt-6/qsqlfield.html#requiredStatus

        **QSqlField::RequiredStatus QSqlField::requiredStatus() const**

        Returns `true` if this is a required field; otherwise returns `false`.
        An `INSERT` will fail if a required field does not have a value.

        **See also** **setRequiredStatus** (), **metaType** (), **length** (),
        **precision** (), **defaultValue** (), and **isGenerated** ().
        """
        ...

    def setAutoValue(self, autoVal: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setAutoValue

        **void QSqlField::setAutoValue(bool autoVal )**

        Marks the field as an auto-generated value if **autoVal** is true.

        **See also** **isAutoValue** ().
        """
        ...

    def setGenerated(self, gen: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setGenerated

        **void QSqlField::setGenerated(bool gen )**

        Sets the generated state. If **gen** is false, no SQL will be generated
        for this field; otherwise, Qt classes such as **QSqlQueryModel**  and
        **QSqlTableModel**  will generate SQL for this field.

        **See also** **isGenerated** (), **setMetaType** (),
        **setRequiredStatus** (), **setLength** (), **setPrecision** (),
        **setDefaultValue** (), and **setReadOnly** ().
        """
        ...

    def setSqlType(self, type: int) -> None:
        ...

    def setDefaultValue(self, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setDefaultValue

        **void QSqlField::setDefaultValue(const QVariant & value )**

        Sets the default value used for this field to **value**.

        **See also** **defaultValue** (), **value** (), **setMetaType** (),
        **setRequiredStatus** (), **setLength** (), **setPrecision** (),
        **setGenerated** (), and **setReadOnly** ().
        """
        ...

    def setPrecision(self, precision: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setPrecision

        **void QSqlField::setPrecision(int precision )**

        Sets the field's **precision**. This only affects numeric fields.

        **See also** **precision** (), **setMetaType** (), **setRequiredStatus**
        (), **setLength** (), **setDefaultValue** (), **setGenerated** (), and
        **setReadOnly** ().
        """
        ...

    def setLength(self, fieldLength: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setLength

        **void QSqlField::setLength(int fieldLength )**

        Sets the field's length to **fieldLength**. For strings this is the
        maximum number of characters the string can hold; the meaning varies for
        other types.

        **See also** **length** (), **setMetaType** (), **setRequiredStatus**
        (), **setPrecision** (), **setDefaultValue** (), **setGenerated** (),
        and **setReadOnly** ().
        """
        ...

    def setRequired(self, required: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setRequired

        **void QSqlField::setRequired(bool required )**

        Sets the required status of this field to **Required**  if **required**
        is true; otherwise sets it to **Optional** .

        **See also** **setRequiredStatus** () and **requiredStatus** ().
        """
        ...

    def setRequiredStatus(self, status: "QSqlField.RequiredStatus") -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setRequiredStatus

        **void QSqlField::setRequiredStatus(QSqlField::RequiredStatus required
        )**

        Sets the required status of this field to **required**.

        **See also** **requiredStatus** (), **setMetaType** (), **setLength**
        (), **setPrecision** (), **setDefaultValue** (), **setGenerated** (),
        and **setReadOnly** ().
        """
        ...

    def isAutoValue(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#isAutoValue

        **bool QSqlField::isAutoValue() const**

        Returns `true` if the value is auto-generated by the database, for
        example auto-increment primary key values.

        **Note:** When using the ODBC driver, due to limitations in the ODBC
        API, the `isAutoValue()` field is only populated in a **QSqlField**
        resulting from a **QSqlRecord**  obtained by executing a `SELECT` query.
        It is `false` in a **QSqlField**  resulting from a **QSqlRecord**
        returned from **QSqlDatabase::record** () or
        **QSqlDatabase::primaryIndex** ().

        **See also** **setAutoValue** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#clear

        **void QSqlField::clear()**

        Clears the value of the field and sets it to NULL. If the field is read-
        only, nothing happens.

        **See also** **setValue** (), **isReadOnly** (), and **requiredStatus**
        ().
        """
        ...

    def isReadOnly(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#isReadOnly

        **bool QSqlField::isReadOnly() const**

        Returns `true` if the field's value is read-only; otherwise returns
        false.

        **See also** **setReadOnly** (), **metaType** (), **requiredStatus** (),
        **length** (), **precision** (), **defaultValue** (), and
        **isGenerated** ().
        """
        ...

    def setReadOnly(self, readOnly: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setReadOnly

        **void QSqlField::setReadOnly(bool readOnly )**

        Sets the read only flag of the field's value to **readOnly**. A read-
        only field cannot have its value set with **setValue** () and cannot be
        cleared to NULL with **clear** ().

        **See also** **isReadOnly** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#isNull

        **bool QSqlField::isNull() const**

        Returns `true` if the field's value is NULL; otherwise returns false.

        **See also** **value** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#name

        **QString QSqlField::name() const**

        Returns the name of the field.

        **See also** **setName** ().
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setName

        **void QSqlField::setName(const QString & name )**

        Sets the name of the field to **name**.

        **See also** **name** ().
        """
        ...

    def value(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#value

        **QVariant QSqlField::value() const**

        Returns the value of the field as a **QVariant** .

        Use **isNull** () to check if the field's value is NULL.

        **See also** **setValue** ().
        """
        ...

    def setValue(self, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qsqlfield.html#setValue

        **void QSqlField::setValue(const QVariant & value )**

        Sets the value of the field to **value**. If the field is read-only
        (**isReadOnly** () returns `true`), nothing happens.

        If the data type of **value** differs from the field's current data
        type, an attempt is made to cast it to the proper type. This preserves
        the data type of the field in the case of assignment, e.g. a **QString**
        to an integer data type.

        To set the value to NULL, use **clear** ().

        **See also** **value** (), **isReadOnly** (), and **defaultValue** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsLayout(QGraphicsLayoutItem):
    """
    https://doc.qt.io/qt-6/qgraphicslayout.html

    **Detailed Description**

    QGraphicsLayout is an abstract class that defines a virtual API for
    arranging **QGraphicsWidget**  children and other **QGraphicsLayoutItem**
    objects for a **QGraphicsWidget** . **QGraphicsWidget**  assigns
    responsibility to a QGraphicsLayout through **QGraphicsWidget::setLayout**
    (). As the widget is resized, the layout will automatically arrange the
    widget's children. QGraphicsLayout inherits **QGraphicsLayoutItem** , so, it
    can be managed by any layout, including its own subclasses.

    **Writing a Custom Layout**

    You can use QGraphicsLayout as a base to write your own custom layout (e.g.,
    a flowlayout), but it is more common to use one of its subclasses instead -
    **QGraphicsLinearLayout**  or **QGraphicsGridLayout** . When creating a
    custom layout, the following functions must be reimplemented as a bare
    minimum:

    FunctionDescription
    **QGraphicsLayoutItem::setGeometry** ()Notifies you
    when the geometry of the layout is set. You can store the geometry in your
    own layout class in a reimplementation of this function.
    **QGraphicsLayoutItem::sizeHint** ()Returns the layout's size hints.
    **QGraphicsLayout::count** ()Returns the number of items in your layout.
    **QGraphicsLayout::itemAt** ()Returns a pointer to an item in your layout.
    **QGraphicsLayout::removeAt** ()Removes an item from your layout without
    destroying it.

    For more details on how to implement each function, refer to the individual
    function documentation.

    Each layout defines its own API for arranging widgets and layout items. For
    example, with a grid layout, you require a row and a column index with
    optional row and column spans, alignment, spacing, and more. A linear
    layout, however, requires a single row or column index to position its
    items. For a grid layout, the order of insertion does not affect the layout
    in any way, but for a linear layout, the order is essential. When writing
    your own layout subclass, you are free to choose the API that best suits
    your layout.

    QGraphicsLayout provides the **addChildLayoutItem** () convenience function
    to add layout items to a custom layout. The function will automatically
    reparent graphics items, if required.

    **Activating the Layout**

    When the layout's geometry changes, QGraphicsLayout immediately rearranges
    all of its managed items by calling **setGeometry** () on each item. This
    rearrangement is called **activating** the layout.

    QGraphicsLayout updates its own geometry to match the **contentsRect** () of
    the **QGraphicsLayoutItem**  it is managing. Thus, it will automatically
    rearrange all its items when the widget is resized. QGraphicsLayout caches
    the sizes of all its managed items to avoid calling **setGeometry** () too
    often.

    **Note:** A QGraphicsLayout will have the same geometry as the
    **contentsRect** () of the widget (not the layout) it is assigned to.

    **Activating the Layout Implicitly**

    The layout can be activated implicitly using one of two ways: by calling
    **activate** () or by calling **invalidate** (). Calling **activate** ()
    activates the layout immediately. In contrast, calling **invalidate** () is
    delayed, as it posts a **LayoutRequest**  event to the managed widget. Due
    to event compression, the **activate** () will only be called once after
    control has returned to the event loop. This is referred to as
    **invalidating** the layout. Invalidating the layout also invalidates any
    cached information. Also, the **invalidate** () function is a virtual
    function. So, you can invalidate your own cache in a subclass of
    QGraphicsLayout by reimplementing this function.

    **Event Handling**

    QGraphicsLayout listens to events for the widget it manages through the
    virtual **widgetEvent** () event handler. When the layout is assigned to a
    widget, all events delivered to the widget are first processed by
    **widgetEvent** (). This allows the layout to be aware of any relevant state
    changes on the widget such as visibility changes or layout direction
    changes.

    **Margin Handling**

    The margins of a QGraphicsLayout can be modified by reimplementing
    **setContentsMargins** () and **getContentsMargins** ().
    """

    def __init__(self, parent: typing.Optional[QGraphicsLayoutItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#QGraphicsLayout

        **QGraphicsLayout::QGraphicsLayout(QGraphicsLayoutItem * parent =
        nullptr)**

        Constructs a QGraphicsLayout object.

        **parent** is passed to **QGraphicsLayoutItem** 's constructor and the
        **QGraphicsLayoutItem** 's isLayout argument is set to **true**.

        If **parent** is a **QGraphicsWidget**  the layout will be installed on
        that widget. (Note that installing a layout will delete the old one
        installed.)
        """
        ...

    def addChildLayoutItem(self, layoutItem: QGraphicsLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#addChildLayoutItem

        **[protected] void
        QGraphicsLayout::addChildLayoutItem(QGraphicsLayoutItem * layoutItem )**

        This function is a convenience function provided for custom layouts, and
        will go through all items in the layout and reparent their graphics
        items to the closest **QGraphicsWidget**  ancestor of the layout.

        If **layoutItem** is already in a different layout, it will be removed
        from that layout.

        If custom layouts want special behaviour they can ignore to use this
        function, and implement their own behaviour.

        **See also** **graphicsItem** ().
        """
        ...

    def updateGeometry(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#updateGeometry

        **[override virtual] void QGraphicsLayout::updateGeometry()**

        Reimplements: **QGraphicsLayoutItem::updateGeometry** ().
        """
        ...

    def removeAt(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#removeAt

        **[pure virtual] void QGraphicsLayout::removeAt(int index )**

        This pure virtual function must be reimplemented in a subclass of
        **QGraphicsLayout**  to remove the item at **index**. The
        reimplementation can assume that **index** is valid (i.e., it respects
        the value of **count** ()).

        The implementation must ensure that the **parentLayoutItem** () of the
        removed item does not point to this layout, since the item is considered
        to be removed from the layout hierarchy.

        If the layout is to be reused between applications, we recommend that
        the layout deletes the item, but the graphics view framework does not
        depend on this.

        The subclass is free to decide how to store the items.

        **See also** **itemAt** () and **count** ().
        """
        ...

    def itemAt(self, i: int) -> QGraphicsLayoutItem:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#itemAt

        **[pure virtual] QGraphicsLayoutItem *QGraphicsLayout::itemAt(int i )
        const**

        This pure virtual function must be reimplemented in a subclass of
        **QGraphicsLayout**  to return a pointer to the item at index **i**. The
        reimplementation can assume that **i** is valid (i.e., it respects the
        value of **count** ()). Together with **count** (), it is provided as a
        means of iterating over all items in a layout.

        The subclass is free to decide how to store the items, and the visual
        arrangement does not have to be reflected through this function.

        **See also** **count** () and **removeAt** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#count

        **[pure virtual] int QGraphicsLayout::count() const**

        This pure virtual function must be reimplemented in a subclass of
        **QGraphicsLayout**  to return the number of items in the layout.

        The subclass is free to decide how to store the items.

        **See also** **itemAt** () and **removeAt** ().
        """
        ...

    def widgetEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#widgetEvent

        **[virtual] void QGraphicsLayout::widgetEvent(QEvent * e )**

        This virtual event handler receives all events for the managed widget.
        **QGraphicsLayout**  uses this event handler to listen for layout
        related events such as geometry changes, layout changes or layout
        direction changes.

        **e** is a pointer to the event.

        You can reimplement this event handler to track similar events for your
        own custom layout.

        **See also** **QGraphicsWidget::event** () and
        **QGraphicsItem::sceneEvent** ().
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#invalidate

        **[virtual] void QGraphicsLayout::invalidate()**

        Clears any cached geometry and size hint information in the layout, and
        posts a **LayoutRequest**  event to the managed parent
        **QGraphicsLayoutItem** .

        **See also** **activate** () and **setGeometry** ().
        """
        ...

    def isActivated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#isActivated

        **bool QGraphicsLayout::isActivated() const**

        Returns `true` if the layout is currently being activated; otherwise,
        returns `false`. If the layout is being activated, this means that it is
        currently in the process of rearranging its items (i.e., the
        **activate** () function has been called, and has not yet returned).

        **See also** **activate** () and **invalidate** ().
        """
        ...

    def activate(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#activate

        **void QGraphicsLayout::activate()**

        Activates the layout, causing all items in the layout to be immediately
        rearranged. This function is based on calling **count** () and
        **itemAt** (), and then calling **setGeometry** () on all items
        sequentially. When activated, the layout will adjust its geometry to its
        parent's **contentsRect** (). The parent will then invalidate any layout
        of its own.

        If called in sequence or recursively, e.g., by one of the arranged items
        in response to being resized, this function will do nothing.

        Note that the layout is free to use geometry caching to optimize this
        process. To forcefully invalidate any such cache, you can call
        **invalidate** () before calling activate().

        **See also** **invalidate** ().
        """
        ...

    def getContentsMargins(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#getContentsMargins

        **[override virtual] void QGraphicsLayout::getContentsMargins(qreal *
        left , qreal * top , qreal * right , qreal * bottom ) const**

        Reimplements: **QGraphicsLayoutItem::getContentsMargins(qreal *left,
        qreal *top, qreal *right, qreal *bottom) const** .
        """
        ...

    def setContentsMargins(
        self, left: float, top: float, right: float, bottom: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayout.html#setContentsMargins

        **void QGraphicsLayout::setContentsMargins(qreal left , qreal top ,
        qreal right , qreal bottom )**

        Sets the contents margins to **left** , **top** , **right** and
        **bottom**. The default contents margins for toplevel layouts are style
        dependent (by querying the pixelMetric for
        **QStyle::PM_LayoutLeftMargin** , **QStyle::PM_LayoutTopMargin** ,
        **QStyle::PM_LayoutRightMargin**  and **QStyle::PM_LayoutBottomMargin**
        ).

        For sublayouts the default margins are 0.

        Changing the contents margins automatically invalidates the layout.

        **See also** **invalidate** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QGenericReturnArgument(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qgenericreturnargument.html

    **Detailed Description**

    This class should never be used directly. Please use the **Q_RETURN_ARG** ()
    macro instead.

    **See also** **Q_RETURN_ARG** (), **QMetaObject::invokeMethod** (), and
    **QGenericArgument** .
    """

    ...
